'use client'

import React from 'react'
import { motion } from 'framer-motion'

interface CallToActionProps {
  title: string
  subtitle: string
  highlightWord: string
  buttonOneText: string
  buttonOneLink: string
  buttonTwoText: string
  buttonTwoLink: string
}

const CallToActionSection: React.FC<CallToActionProps> = ({
  title,
  subtitle,
  highlightWord,
  buttonOneText,
  buttonOneLink,
  buttonTwoText,
  buttonTwoLink
}) => {
  return (
    <section className="cta-section py-16 px-4 bg-white">
      <div className="cta-container max-w-4xl mx-auto text-center">
        <motion.h2 
          className="cta-title text-4xl md:text-5xl font-bold text-gray-800 mb-4"
          initial={{ opacity: 0, y: -20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.5 }}
        >
          {title}
        </motion.h2>
        <motion.p 
          className="cta-subtitle text-gray-600 text-lg mb-8"
          initial={{ opacity: 0, y: -20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.5, delay: 0.2 }}
        >
          {subtitle.split(highlightWord).map((part, index, array) => (
            <React.Fragment key={index}>
              {part}
              {index < array.length - 1 && (
                <span className="cta-highlight text-pink-500">{highlightWord}</span>
              )}
            </React.Fragment>
          ))}
        </motion.p>
        <motion.div 
          className="cta-button-group flex flex-col sm:flex-row justify-center items-center gap-4"
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.5, delay: 0.4 }}
        >
          <motion.a
            href={buttonOneLink}
            className="cta-call-btn w-full sm:w-auto px-8 py-3 bg-green-500 text-white rounded-full font-semibold hover:bg-green-600 focus:outline-none focus:ring-2 focus:ring-green-500 focus:ring-opacity-50"
            whileHover={{ scale: 1.05 }}
            whileTap={{ scale: 0.95 }}
          >
            {buttonOneText}
          </motion.a>
          <motion.a
            href={buttonTwoLink}
            className="cta-whatsapp-btn w-full sm:w-auto px-8 py-3 bg-green-300 text-white rounded-full font-semibold hover:bg-green-400 focus:outline-none focus:ring-2 focus:ring-green-300 focus:ring-opacity-50"
            whileHover={{ scale: 1.05 }}
            whileTap={{ scale: 0.95 }}
          >
            {buttonTwoText}
          </motion.a>
        </motion.div>
      </div>
    </section>
  )
}

export default CallToActionSection